==> nextcloud-32.0.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/files_external/l10n/sc.js <==
OC.L10N.register(
    "files_external",
    {
    "Grant access" : "Permite s'atzessu",
    "Error configuring OAuth2" : "Errore de cunfiguratzione OAuth2",
    "Generate keys" : "Gènera craes",
    "Error generating key pair" : "Errore creende sa croba de craes",
    "Storage with ID \"%d\" not found" : "Archiviatzione cun ID \"%d\" no agatadu",
    "Invalid backend or authentication mechanism class" : "Su motore o sa casta de su mecanìsmu non balent",
    "Invalid mount point" : "Puntu de montàgiu imbàlidu",
    "Objectstore forbidden" : "Butega de datos vietada",
    "Invalid storage backend \"%s\"" : "Motore de archiviatzione \"%s\" non bàlidu",
    "Not permitted to use backend \"%s\"" : "Motore de archiviatzione \"%s\" non permìtidu",
    "Not permitted to use authentication mechanism \"%s\"" : "Impreu de su mecanismu de autenticatzione \"%s\" non permìtidu",
    "Unsatisfied backend parameters" : "Non rispetat is paràmetros de su motore ",
    "Unsatisfied authentication mechanism parameters" : "Is paràmetros de su mecanismu de autenticatzione no sunt rispetados",
    "Insufficient data: %s" : "Datos non sufitzientes: %s",
    "%s" : "%s",
    "Access key" : "Crae de atzessu",
    "Secret key" : "Crae segreta",
    "Builtin" : "Integrada",
    "None" : "Perunu",
    "OAuth2" : "OAuth2",
    "Client ID" : "ID cliente",
    "Client secret" : "Segretu de su cliente",
    "OpenStack v2" : "OpenStack v2",
    "Login" : "Atzessu",
    "Password" : "Crae",
    "Tenant name" : "Nùmene de tenant",
    "Identity endpoint URL" : "Puntu finale URL de is identidades",
    "OpenStack v3" : "OpenStack v3",
    "Domain" : "Domìniu",
    "Rackspace" : "Rackspace",
    "API key" : "Crae API",
    "Global credentials" : "Credentziales globales",
    "Log-in credentials, save in database" : "Credentziales de atzessu, sarva in sa base de datos",
    "Log-in credentials, save in session" : "Credentziales de atzessu, sarva in sa sessione",
    "RSA public key" : "Crae pùblica RSA",
    "Public key" : "Crae pùblica",
    "RSA private key" : "Crae privada RSA",
    "Private key" : "Crae privada",
    "Kerberos ticket" : "Billete de Kerberos",
    "Bucket" : "Bucket",
    "Hostname" : "Nùmene retzidore",
    "Port" : "Porta",
    "Region" : "Regione",
    "Enable SSL" : "Ativa SSL",
    "Enable Path Style" : "Ativa istile de percursu",
    "Legacy (v2) authentication" : "Autenticatzione traditzionale (v2)",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Sutacartella remota",
    "Secure https://" : "Protocollu seguru https:// ",
    "FTP" : "FTP",
    "Host" : "Retzidore",
    "Secure ftps://" : "Protocollu seguru ftps:// ",
    "Local" : "Locale",
    "Location" : "Positzione",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Sorgente",
    "SFTP with secret key login" : "SFTP cun crae de atzessu segreta",
    "SMB/CIFS" : "SMB/CIFS",
    "Share" : "Cumpartzi",
    "Show hidden files" : "Mustra archìvios cuados",
    "Verify ACL access when listing files" : "Cumproare s'atzessu ACL cando s'elencant is archìvios",
    "Timeout" : "Agabbadu su tempus",
    "SMB/CIFS using OC login" : "SMB/CIFS cun atzessu OC",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Nùmene de su servìtziu",
    "Request timeout (seconds)" : "Tempus màssimu de sa rechesta (segundos)",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Su suportu cURL in PHP no est ativadu o installadu. Non faghet a montare %s. Dimanda a s'amministratzione de sistema pro dd'installare.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Su suportu FTP in PHP no est ativadu o installadu. Non faghet a montare %s. Dimanda a s'amministratzione de sistema pro dd'installare.",
    "\"%1$s\" is not installed. Mounting of %2$s is not possible. Please ask your system administrator to install it." : "\"%1$s\" no est installadu. Non faghet a montare%2$s. Dimanda a s'amministratzione de sistema pro dd'installare.",
    "External storage" : "Archiviatzione de foras",
    "External storage support" : "Suportu archiviatzione de foras",
    "Adds basic external storage support" : "Agiunghet suportu de base pro archiviatziones de foras",
    "Confirm" : "Cunfirma",
    "New configuration successfully saved" : "Cunfiguratzione noa sarvada",
    "Open in Files" : "Aberi in Archìvios",
    "External mount error" : "Errore de montàgiu esternu",
    "Storage type" : "Genia de archiviatzione",
    "Unknown" : "Disconnotu",
    "Scope" : "Àmbitu",
    "Personal" : "Personale",
    "System" : "Sistema",
    "(Group)" : "(Grupu)",
    "Compatibility with Mac NFD encoding (slow)" : " Compatibilidade cun sa codìfica Mac NFD (lentu)",
    "Enable encryption" : "Ativa tzifradura",
    "Enable previews" : "Ativa anteprimas",
    "Enable sharing" : "Ativa cumpartzidura",
    "Check for changes" : "Controlla is càmbios",
    "Never" : "Mais",
    "Once every direct access" : "Una borta pro ogni atzessu diretu",
    "Read only" : "Letura sola",
    "Admin defined" : "Definidu dae s'amministradore",
    "Delete storage?" : "Nche cheres cantzellare sa memòria?",
    "Click to recheck the configuration" : "Incarca pro controllare torra sa cunfiguratzione",
    "Saved" : "Sarvadu",
    "Saving …" : "Sarvende ...",
    "Save" : "Sarva",
    "No external storage configured or you don't have the permission to configure them" : "Peruna archiviatzione de foras cunfigurada o non tenes is permissos pro ddas cunfigurare",
    "Open documentation" : "Aberi sa documentatzione",
    "Folder name" : "Nùmene de sa cartella",
    "Authentication" : "Autenticatzione",
    "Configuration" : "Cunfiguratzione",
    "Available for" : "A disponimentu pro",
    "Add storage" : "Agiunghe archiviatzione",
    "Advanced settings" : "Cunfiguratziones avantzadas",
    "Global credentials can be used to authenticate with multiple external storages that have the same credentials." : "Is credentziales globales si podent impreare puru pro s'autenticatzione cun prus archiviatziones de foras chi tenent is matessi credentziales.",
    "Error configuring OAuth1" : "Errore de cunfiguratzione OAuth1",
    "Please provide a valid app key and secret." : "Fruni una crae bàlida e segreta.",
    "OAuth1" : "OAuth1",
    "App key" : "Crae de s'aplicatzione",
    "App secret" : "Segretu de s'aplicatzione",
    "Saving …" : "Sarvende ..."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-32.0.5-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/files_external/l10n/sc.js <==
OC.L10N.register(
    "files_external",
    {
    "Storage with ID \"%d\" not found" : "Archiviatzione cun ID \"%d\" no agatadu",
    "Invalid backend or authentication mechanism class" : "Su motore o sa casta de su mecanìsmu non balent",
    "Invalid mount point" : "Puntu de montàgiu imbàlidu",
    "Objectstore forbidden" : "Butega de datos vietada",
    "Invalid storage backend \"%s\"" : "Motore de archiviatzione \"%s\" non bàlidu",
    "Not permitted to use backend \"%s\"" : "Motore de archiviatzione \"%s\" non permìtidu",
    "Not permitted to use authentication mechanism \"%s\"" : "Impreu de su mecanismu de autenticatzione \"%s\" non permìtidu",
    "Unsatisfied backend parameters" : "Non rispetat is paràmetros de su motore ",
    "Unsatisfied authentication mechanism parameters" : "Is paràmetros de su mecanismu de autenticatzione no sunt rispetados",
    "Insufficient data: %s" : "Datos non sufitzientes: %s",
    "Access key" : "Crae de atzessu",
    "Secret key" : "Crae segreta",
    "Builtin" : "Integrada",
    "None" : "Perunu",
    "OpenStack v2" : "OpenStack v2",
    "Login" : "Atzessu",
    "Password" : "Crae",
    "Tenant name" : "Nùmene de tenant",
    "Identity endpoint URL" : "Puntu finale URL de is identidades",
    "OpenStack v3" : "OpenStack v3",
    "Domain" : "Domìniu",
    "Rackspace" : "Rackspace",
    "API key" : "Crae API",
    "Global credentials" : "Credentziales globales",
    "Log-in credentials, save in database" : "Credentziales de atzessu, sarva in sa base de datos",
    "Log-in credentials, save in session" : "Credentziales de atzessu, sarva in sa sessione",
    "RSA public key" : "Crae pùblica RSA",
    "Public key" : "Crae pùblica",
    "RSA private key" : "Crae privada RSA",
    "Private key" : "Crae privada",
    "Kerberos ticket" : "Billete de Kerberos",
    "Bucket" : "Bucket",
    "Hostname" : "Nùmene retzidore",
    "Port" : "Porta",
    "Proxy" : "Proxy",
    "Region" : "Regione",
    "Enable SSL" : "Ativa SSL",
    "Enable Path Style" : "Ativa istile de percursu",
    "Legacy (v2) authentication" : "Autenticatzione traditzionale (v2)",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Sutacartella remota",
    "Secure https://" : "Protocollu seguru https:// ",
    "FTP" : "FTP",
    "Host" : "Retzidore",
    "Secure ftps://" : "Protocollu seguru ftps:// ",
    "Local" : "Locale",
    "Location" : "Positzione",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Sorgente",
    "SFTP with secret key login" : "SFTP cun crae de atzessu segreta",
    "SMB/CIFS" : "SMB/CIFS",
    "Share" : "Cumpartzi",
    "Show hidden files" : "Mustra archìvios cuados",
    "Verify ACL access when listing files" : "Cumproare s'atzessu ACL cando s'elencant is archìvios",
    "Timeout" : "Agabbadu su tempus",
    "SMB/CIFS using OC login" : "SMB/CIFS cun atzessu OC",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Nùmene de su servìtziu",
    "Request timeout (seconds)" : "Tempus màssimu de sa rechesta (segundos)",
    "External storage" : "Archiviatzione de foras",
    "External storage support" : "Suportu archiviatzione de foras",
    "Adds basic external storage support" : "Agiunghet suportu de base pro archiviatziones de foras",
    "Add storage" : "Agiunghe archiviatzione",
    "Folder name" : "Nùmene de sa cartella",
    "Authentication" : "Autenticatzione",
    "Cancel" : "Cancel",
    "Edit" : "Modìfica",
    "Create" : "Crea",
    "Never" : "Mais",
    "Once every direct access" : "Una borta pro ogni atzessu diretu",
    "Always" : "Semper",
    "Read only" : "Letura sola",
    "Enable previews" : "Ativa anteprimas",
    "Enable sharing" : "Ativa cumpartzidura",
    "Enable encryption" : "Ativa tzifradura",
    "Compatibility with Mac NFD encoding (slow)" : " Compatibilidade cun sa codìfica Mac NFD (lentu)",
    "External storages" : "Archiviatzione de foras",
    "Status" : "Status",
    "Actions" : "Atziones",
    "Delete" : "Cantzella",
    "Saved" : "Sarvadu",
    "Error generating key pair" : "Errore creende sa croba de craes",
    "Key size" : "Mannària de sa crae",
    "Generate keys" : "Gènera craes",
    "Confirm" : "Cunfirma",
    "Global credentials can be used to authenticate with multiple external storages that have the same credentials." : "Is credentziales globales si podent impreare puru pro s'autenticatzione cun prus archiviatziones de foras chi tenent is matessi credentziales.",
    "Saving …" : "Sarvende ...",
    "Save" : "Sarva",
    "New configuration successfully saved" : "Cunfiguratzione noa sarvada",
    "Open in Files" : "Aberi in Archìvios",
    "External mount error" : "Errore de montàgiu esternu",
    "Open settings" : "Aberi sa cunfiguratzione",
    "Ignore" : "Ignora",
    "Storage type" : "Genia de archiviatzione",
    "Unknown" : "Disconnotu",
    "Scope" : "Àmbitu",
    "Personal" : "Personale",
    "System" : "Sistema",
    "Error" : "Errore",
    "Unauthorized" : "Peruna autorizatzione",
    "Network error" : "Errore de rete",
    "Grant access" : "Permite s'atzessu",
    "Error configuring OAuth1" : "Errore de cunfiguratzione OAuth1",
    "Please provide a valid app key and secret." : "Fruni una crae bàlida e segreta.",
    "Error configuring OAuth2" : "Errore de cunfiguratzione OAuth2",
    "%s" : "%s",
    "OAuth1" : "OAuth1",
    "App key" : "Crae de s'aplicatzione",
    "App secret" : "Segretu de s'aplicatzione",
    "OAuth2" : "OAuth2",
    "Client ID" : "ID cliente",
    "Client secret" : "Segretu de su cliente",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Su suportu cURL in PHP no est ativadu o installadu. Non faghet a montare %s. Dimanda a s'amministratzione de sistema pro dd'installare.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Su suportu FTP in PHP no est ativadu o installadu. Non faghet a montare %s. Dimanda a s'amministratzione de sistema pro dd'installare.",
    "\"%1$s\" is not installed. Mounting of %2$s is not possible. Please ask your system administrator to install it." : "\"%1$s\" no est installadu. Non faghet a montare%2$s. Dimanda a s'amministratzione de sistema pro dd'installare.",
    "(Group)" : "(Grupu)",
    "Check for changes" : "Controlla is càmbios",
    "Admin defined" : "Definidu dae s'amministradore",
    "Delete storage?" : "Nche cheres cantzellare sa memòria?",
    "Click to recheck the configuration" : "Incarca pro controllare torra sa cunfiguratzione",
    "Saving …" : "Sarvende ...",
    "No external storage configured or you don't have the permission to configure them" : "Peruna archiviatzione de foras cunfigurada o non tenes is permissos pro ddas cunfigurare",
    "Open documentation" : "Aberi sa documentatzione",
    "Configuration" : "Cunfiguratzione",
    "Available for" : "A disponimentu pro",
    "Advanced settings" : "Cunfiguratziones avantzadas"
},
"nplurals=2; plural=(n != 1);");
